#include <stdio.h>
#include <string.h>

#include <profapi.h>

#include "blink.h"

static struct blink_backend *led;

extern void blink(enum event);
extern void prof_cons_error(const char *);

static void
cmd_show_info()
{
	char buf[64];

	snprintf(buf, sizeof(buf), "Current backend: %s", led->name);
	prof_cons_show(buf);
}

static void
cmd_test()
{
	prof_cons_show("Blinking");
	blink(NEW_MSG);
}

static void
cmd_led_off()
{
	prof_cons_show("LED off");
	blink(LED_OFF);
}

static void
cmd_cb(char **args)
{
	const char *cmd;
	char msg[32];
	int i;

	for (i = 0; args[i] != NULL; i++)
	{
		cmd = args[i];
		if (!strcmp(cmd, "test"))
		{
			cmd_test();
		}
		else if (!strcmp(cmd, "info"))
		{
			cmd_show_info();
		}
		else if (!strcmp(cmd, "off"))
		{
			cmd_led_off();
		}
		else
		{
			snprintf(msg, sizeof(msg), "Unknown command: %s", cmd);
			prof_cons_error(msg);
		}
	}
}

void
blink_cmd_init(struct blink_backend *backend)
{
	led = backend;

	char *synopsis[2];
	synopsis[0] = "/blink info|test|off";
	synopsis[1] = NULL;

	char *arguments[4][2];
	arguments[0][0] = "info";
	arguments[0][1] = "Show information about the current LED backend";

	arguments[1][0] = "test";
	arguments[1][1] = "Test the LED (blink message pattern)";

	arguments[2][0] = "off";
	arguments[2][1] = "Turn off the LED";

	arguments[3][0] = NULL;
	arguments[3][1] = NULL;

	char *examples[1];
	examples[0] = NULL;

	char *desc = "Control the blink plugin.";

	prof_register_command("/blink", 1, 1, synopsis, desc, arguments,
		examples, cmd_cb);
}
